@@ -1063,8 +1063,7 @@ class ServiceStub(ABC):
     def _do_twirp_rpc(self, api, request: Message, response: Message):
         api = api + self.suffix_url
         url = self._target + "/twirp" + api
-        logger.info(f'[请求URL]:{url}')
-        logger.info(f'[请求数据]:{request.to_json()}')
+        logger.info(f'\n[请求URL]:{url}\n[请求数据]:{request.to_json()}')
         r = session.request(
             method="POST" or self.kwargs.get("method"),
             url=url or self.kwargs.get("url"),
@@ -1083,9 +1082,8 @@ class ServiceStub(ABC):
         except Exception:
             r_data = r.text
         
-        response_log = f'\n[响应结果]:{r_data}\n[响应http_code]:{r.status_code}\n' \
-                       f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒\n[响应X-Trace-Id]:{r.headers.get("X-Trace-Id")}\n'
-        logger.info(response_log)
+        logger.info(f'\n[响应http_code]:{r.status_code}\n[响应X-Trace-Id]:{r.headers.get("X-Trace-Id")}\n'
+                    f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒\n[响应结果]:{r_data}\n')
         # logger.info(f'[响应结果]:{r_data}')
         # logger.info(f'[响应http_code]:{r.status_code}')
         # logger.info(f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒')
